pyglet.shapes
=============

.. automodule:: pyglet.shapes

.. autoclass:: ShapeBase
   
  .. rubric:: Methods
   
  .. automethod:: draw
  .. automethod:: delete
    
  .. rubric:: Attributes
  
  .. autoattribute:: x
  .. autoattribute:: y
  .. autoattribute:: position
  .. autoattribute:: rotation
  .. autoattribute:: anchor_x
  .. autoattribute:: anchor_y
  .. autoattribute:: anchor_position
  .. autoattribute:: color
  .. autoattribute:: opacity
  .. autoattribute:: visible
  .. autoattribute:: group
  .. autoattribute:: batch


.. autoclass:: Arc
  :show-inheritance:

  .. autoattribute:: angle
  .. autoattribute:: start_angle
  .. autoattribute:: thickness


.. autoclass:: BezierCurve
  :show-inheritance:

  .. autoattribute:: points
  .. autoattribute:: t
  .. autoattribute:: thickness


.. autoclass:: Circle
  :show-inheritance:

  .. autoattribute:: radius


.. autoclass:: Ellipse
  :show-inheritance:

  .. autoattribute:: a
  .. autoattribute:: b


.. autoclass:: Sector
  :show-inheritance:

  .. autoattribute:: angle
  .. autoattribute:: start_angle
  .. autoattribute:: radius


.. autoclass:: Line
  :show-inheritance:

  .. autoattribute:: x2
  .. autoattribute:: y2


.. autoclass:: Rectangle
  :show-inheritance:

  .. autoattribute:: width
  .. autoattribute:: height


.. autoclass:: Box
  :show-inheritance:

  .. autoattribute:: width
  .. autoattribute:: height


.. autoclass:: BorderedRectangle
  :show-inheritance:

  .. autoattribute:: width
  .. autoattribute:: height
  .. autoattribute:: border_color


.. autoclass:: Triangle
  :show-inheritance:

  .. autoattribute:: x2
  .. autoattribute:: y2
  .. autoattribute:: x3
  .. autoattribute:: y3


.. autoclass:: Star
  :show-inheritance:

  .. autoattribute:: outer_radius
  .. autoattribute:: inner_radius
  .. autoattribute:: num_spikes


.. autoclass:: Polygon
  :show-inheritance:


.. autoclass:: MultiLine
  :show-inheritance:

  .. autoattribute:: thickness
